@@ -6,11 +6,13 @@ extends 'Zonemaster::Engine::Exception';
 # The actual interesting module.
 package Zonemaster::CLI;
 
-use version; our $VERSION = version->declare("v2.0.3");
-
 use 5.014002;
+
+use strict;
 use warnings;
 
+use version; our $VERSION = version->declare( "v3.0.0" );
+
 use Locale::TextDomain 'Zonemaster-CLI';
 use Moose;
 with 'MooseX::Getopt';
@@ -112,6 +114,13 @@ has 'show_module' => (
     default       => 0,
 );
 
+has 'show_testcase' => (
+    is            => 'ro',
+    isa           => 'Bool',
+    documentation => __( 'Print the name of the test case on entries.' ),
+    default       => 0,
+);
+
 has 'ns' => (
     is            => 'ro',
     isa           => 'ArrayRef',
@@ -322,11 +331,11 @@ sub run {
 
     if ( $self->profile ) {
         say $fh_diag __x( "Loading profile from {path}.", path => $self->profile );
-	my $json    = read_file( $self->profile );
-	my $foo     = Zonemaster::Engine::Profile->from_json( $json );
-	my $profile = Zonemaster::Engine::Profile->default;
-	$profile->merge( $foo );
-	Zonemaster::Engine::Profile->effective->merge( $profile );
+        my $json    = read_file( $self->profile );
+        my $foo     = Zonemaster::Engine::Profile->from_json( $json );
+        my $profile = Zonemaster::Engine::Profile->default;
+        $profile->merge( $foo );
+        Zonemaster::Engine::Profile->effective->merge( $profile );
     }
     else {
 
@@ -337,7 +346,7 @@ sub run {
         }
 
         if ( $self->config ) {
-            say $fh_diag __x( "Loading configuaration from {path}.", path => $self->config );
+            say $fh_diag __x( "Loading configuration from {path}.", path => $self->config );
             say $fh_diag __x( "Use of config and policy have been TERMINATED, use profile instead." );
             exit( 1 );
         }
@@ -366,13 +375,11 @@ sub run {
     my $translator;
     $translator = Zonemaster::Engine::Translator->new unless ( $self->raw or $self->json or $self->json_stream );
     $translator->locale( $self->locale ) if $translator and $self->locale;
-    eval { $translator->data } if $translator;    # Provoke lazy loading of translation data
 
     my $json_translator;
     if ( $self->json_translate ) {
         $json_translator = Zonemaster::Engine::Translator->new;
         $json_translator->locale( $self->locale ) if $self->locale;
-        eval { $json_translator->data };
     }
 
     if ( $self->restore ) {
@@ -397,13 +404,17 @@ sub run {
                     }
 
                     if ( $self->show_level ) {
-                        printf "%-9s ", __( $entry->level );
+                        printf "%-9s ", translate_severity( $entry->level );
                     }
 
                     if ( $self->show_module ) {
                         printf "%-12s ", $entry->module;
                     }
 
+                    if ( $self->show_testcase ) {
+                        printf "%-14s ", $entry->testcase;
+                    }
+
                     say $translator->translate_tag( $entry );
                 }
                 elsif ( $self->json_stream ) {
@@ -411,6 +422,7 @@ sub run {
 
                     $r{timestamp} = $entry->timestamp;
                     $r{module}    = $entry->module;
+                    $r{testcase}  = $entry->testcase;
                     $r{tag}       = $entry->tag;
                     $r{level}     = $entry->level;
                     $r{args}      = $entry->args if $entry->args;
@@ -421,11 +433,17 @@ sub run {
                 elsif ( $self->json ) {
                     # Don't do anything
                 }
-                elsif ( $self->show_module ) {
-                    printf "%7.2f %-9s %-12s %s\n", $entry->timestamp, $entry->level, $entry->module, $entry->string;
-                }
                 else {
-                    printf "%7.2f %-9s %s\n", $entry->timestamp, $entry->level, $entry->string;
+                    my $str = sprintf "%7.2f %-9s ", $entry->timestamp, $entry->level;
+                    if ( $self->show_module ) {
+                        $str.= sprintf "%-12s ", $entry->module;
+                    }
+                    if ( $self->show_testcase ) {
+                        $str.= sprintf "%-14s ", $entry->testcase;
+                    }
+                    my $entry_str = sprintf "%s", $entry->string;
+                    $entry_str =~ s/^([A-Z0-9]+:)*//;
+                    printf "%s%s\n", $str, $entry_str;
                 }
             } ## end if ( $numeric{ uc $entry...})
             if ( $self->stop_level and $numeric{ uc $entry->level } >= $numeric{ $self->stop_level } ) {
@@ -454,6 +472,9 @@ sub run {
         if ( $self->show_module ) {
             print __( 'Module       ' );
         }
+        if ( $self->show_testcase ) {
+            print __( 'Testcase       ' );
+        }
         say __( 'Message' );
 
         if ( $self->time ) {
@@ -465,6 +486,9 @@ sub run {
         if ( $self->show_module ) {
             print __( '============ ' );
         }
+        if ( $self->show_testcase ) {
+            print __( '============== ' );
+        }
         say __( '=======' );
     } ## end if ( $translator )
 
@@ -515,13 +539,13 @@ sub run {
         say __( "\n\n   Level\tNumber of log entries" );
         say "   =====\t=====================";
         foreach my $level ( sort { $numeric{$b} <=> $numeric{$a} } keys %counter ) {
-            printf __( "%8s\t%5d entries.\n" ), __( $level ), $counter{$level};
+            printf __( "%8s\t%5d entries.\n" ), translate_severity( $level ), $counter{$level};
         }
     }
 
     if ( $self->nstimes ) {
         my $zone = Zonemaster::Engine->zone( $domain );
-        my $max = max map { length( "$_" ) } @{ $zone->ns };
+        my $max = max map { length( "$_" ) } ( @{ $zone->ns }, q{Server} );
 
         print "\n";
         printf "%${max}s %s\n", 'Server', ' Max (ms)      Min      Avg   Stddev   Median     Total';
@@ -676,6 +700,31 @@ sub do_dump_profile {
     exit;
 }
 
+sub translate_severity {
+    my $severity = shift;
+    if ( $severity eq "DEBUG" ) {
+        return __( "DEBUG" );
+    }
+    elsif ( $severity eq "INFO" ) {
+        return __( "INFO" );
+    }
+    elsif ( $severity eq "NOTICE" ) {
+        return __( "NOTICE" );
+    }
+    elsif ( $severity eq "WARNING" ) {
+        return __( "WARNING" );
+    }
+    elsif ( $severity eq "ERROR" ) {
+        return __( "ERROR" );
+    }
+    elsif ( $severity eq "CRITICAL" ) {
+        return __( "CRITICAL" );
+    }
+    else {
+        return $severity;
+    }
+}
+
 1;
 
 __END__
